==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/igr-callout-series-selecting-event-args.js <==
import { IgrSeries } from "./igr-series";
import { CalloutSeriesSelectingEventArgs as CalloutSeriesSelectingEventArgs_internal } from "./CalloutSeriesSelectingEventArgs";
/**
 * Represents event arguments for selecting callout layer
*/
var IgrCalloutSeriesSelectingEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrCalloutSeriesSelectingEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrCalloutSeriesSelectingEventArgs.prototype.createImplementation = function () {
        return new CalloutSeriesSelectingEventArgs_internal();
    };
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrCalloutSeriesSelectingEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrCalloutSeriesSelectingEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "xValue", {
        /**
         * Gets data X-value assositated with callout layer
        */
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "yValue", {
        /**
         * Gets data Y-value assositated with callout layer
        */
        get: function () {
            return this.i.d;
        },
        set: function (v) {
            this.i.d = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "item", {
        /**
         * Gets data item assositated with callout layer
        */
        get: function () {
            return this.i.item;
        },
        set: function (v) {
            this.i.item = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "series", {
        /**
         * Gets or sets series object assositated with callout layer
        */
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrSeries._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "seriesName", {
        /**
         * Gets or sets series name assositated with callout layer
        */
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrCalloutSeriesSelectingEventArgs;
}());
export { IgrCalloutSeriesSelectingEventArgs };

==> igniteui-react-charts-19.0.1.tgz: package/esm5/lib/igr-callout-series-selecting-event-args.js <==
import { IgrSeries } from "./igr-series";
import { CalloutSeriesSelectingEventArgs as CalloutSeriesSelectingEventArgs_internal } from "./CalloutSeriesSelectingEventArgs";
/**
 * Represents event arguments for selecting callout layer
*/
var IgrCalloutSeriesSelectingEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrCalloutSeriesSelectingEventArgs() {
        this.mounted = false;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrCalloutSeriesSelectingEventArgs.prototype.createImplementation = function () {
        return new CalloutSeriesSelectingEventArgs_internal();
    };
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "nativeElement", {
        get: function () {
            return this._implementation.nativeElement;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrCalloutSeriesSelectingEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrCalloutSeriesSelectingEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "xValue", {
        /**
         * Gets data X-value associated with callout layer
        */
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "yValue", {
        /**
         * Gets data Y-value associated with callout layer
        */
        get: function () {
            return this.i.d;
        },
        set: function (v) {
            this.i.d = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "item", {
        /**
         * Gets data item associated with callout layer
        */
        get: function () {
            return this.i.item;
        },
        set: function (v) {
            this.i.item = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "series", {
        /**
         * Gets or sets series object associated with callout layer
        */
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrSeries._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutSeriesSelectingEventArgs.prototype, "seriesName", {
        /**
         * Gets or sets series name associated with callout layer
        */
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrCalloutSeriesSelectingEventArgs;
}());
export { IgrCalloutSeriesSelectingEventArgs };
